#ifndef AGILE_SHERPA_SHERPA_HH 
#define AGILE_SHERPA_SHERPA_HH

#include "AGILe/Generator.hh"
#include "Sherpa.H"
#include "HepMC2_Interface.H"


namespace AGILe {

  class Sherpa : public Generator {
  public:
    /// Standard constructor.
    Sherpa(); 

    /// Destructor.
    ~Sherpa() { }

    /// Set up initial state from supplied params.
    void setGenSpecificInitialState(PdgCode p1 = PROTON, double e1 = 7000.0, 
                                      PdgCode p2 = PROTON, double e2 = 7000.0);
    
    /// Run the generator for one event.
    void makeEvent(HepMC::GenEvent& evt);

    /// Ensure that base class setParam is visible.
    using Generator::setParam;
    
    /// Set string-valued parameter.
    bool setParam(const string& name, const string& value) {
      Generator::setParam(name, value);
      _parameters[name] = value;
      return SUCCESS;
    }

    /// Tidy up after ourselves.
    void finalize();

    /// Set the random number generator seed.
    void setSeed(const int value);


  protected:
    /// Set up default params etc.
    void initialize();

    /// Fill a HepMC event.
    void fillEvent(HepMC::GenEvent& evt);

    /// Parameter map.
    std::map<std::string, std::string> _parameters;


  private:
    /// Sherpa generator as data member.
    SHERPA::Sherpa _sherpa;

    /// Sherpa-to-HepMC event converter.
    SHERPA::HepMC2_Interface _hepmcInterface;

  };


}

#endif
